@@ -7,7 +7,7 @@ use Carp qw[croak];
 
 use vars qw[$VERSION $DisablePerl $Untaint $Debug];
 
-$VERSION        = '0.42';
+$VERSION        = '0.44';
 $DisablePerl    = 0;
 $Untaint        = 0;
 $Debug          = 0;
@@ -323,6 +323,10 @@ sub score {
         delete $score{perl} unless ("@$data" =~ /([\$\@\%]\w+)/);
     }
 
+    if ( $score{equal} && $score{space} && $score{equal} == $score{space} ) {
+      $score{equal}++;
+    }
+
     $self->_score( \%score );
 
     return \%score;
